from teraboxdl.downloader import TeraBoxDownloader

__all__ = ["TeraBoxDownloader"]
__version__ = "0.1"
__license__ = "GNU General Public License v3.0"
__author__ = "Santhosh"
print("TeraBoxDL package has been imported successfully.")
print(f"Version: {__version__}")
print(f"License: {__license__}")
